import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["maxRows", "itemWidth", "columnGap", "maxColumns", "minColumns"],
    _excluded2 = ["maxRows", "maxColumns", "minColumns", "items", "itemWidth", "initialValues", "size", "cache", "hasSearchBtn", "columnGap", "onSubmit", "onReset", "onValueChange", "onCreate"];
import React, { useMemo, Fragment, useEffect } from 'react';
import { Form, FormGrid, FormButtonGroup, Submit, Reset } from '@formily/antd';
import { DownOutlined, UpOutlined } from '@ant-design/icons';
import { observer, Observer, FormProvider } from '@formily/react';
import { observable } from '@formily/reactive';
import { createForm, onFormValuesChange, onFormInit } from '@formily/core';
import { useLocalStorageState, useSessionStorageState, useKeyPress } from 'ahooks';
import { useCollapseGrid } from "./useCollapseGrid";
import styles from "./index.module.less";
import { YwJsonForm } from "../YwJsonForm";
import { isFunction } from "../../utils/index";
var obs = observable({
  value: true
});
var QueryForm = observer(function (_ref) {
  var maxRows = _ref.maxRows,
      itemWidth = _ref.itemWidth,
      columnGap = _ref.columnGap,
      maxColumns = _ref.maxColumns,
      minColumns = _ref.minColumns,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useCollapseGrid = useCollapseGrid({
    maxRows: maxRows,
    itemWidth: itemWidth,
    maxColumns: maxColumns,
    minColumns: minColumns,
    columnGap: columnGap
  }),
      grid = _useCollapseGrid.grid,
      expanded = _useCollapseGrid.expanded,
      toggle = _useCollapseGrid.toggle,
      isLine = _useCollapseGrid.isLine,
      type = _useCollapseGrid.type;

  obs.value = isLine;

  var renderButtonGroup = function renderButtonGroup() {
    if (type === 'collapsible') {
      return /*#__PURE__*/React.createElement(Fragment, null, /*#__PURE__*/React.createElement(FormButtonGroup, null, /*#__PURE__*/React.createElement("a", {
        style: {
          color: '#666',
          fontSize: '12px'
        },
        href: "",
        onClick: function onClick(e) {
          e.preventDefault();
          toggle();
        }
      }, !expanded ? /*#__PURE__*/React.createElement(React.Fragment, null, "\u5C55\u5F00", /*#__PURE__*/React.createElement(DownOutlined, {
        style: {
          marginLeft: '9px',
          color: '#999'
        }
      })) : /*#__PURE__*/React.createElement(React.Fragment, null, "\u6536\u8D77", /*#__PURE__*/React.createElement(UpOutlined, {
        style: {
          marginLeft: '9px',
          color: '#999'
        }
      })))));
    }
  };

  return /*#__PURE__*/React.createElement(Form, _extends({}, props, {
    feedbackLayout: "terse"
  }), /*#__PURE__*/React.createElement(FormGrid, {
    grid: grid
  }, props.children, /*#__PURE__*/React.createElement(FormGrid.GridColumn, {
    gridSpan: 24,
    style: {
      display: 'flex',
      justifyContent: 'center'
    }
  }, renderButtonGroup())));
});

var useCache = function useCache(key, props) {
  if (props === void 0) {
    props = {
      type: 'sessionStorage'
    };
  }

  var useHook = props.type === 'sessionStorage' ? useSessionStorageState : useLocalStorageState;

  var _useHook = useHook(key, _extends({
    defaultValue: undefined
  }, props)),
      message = _useHook[0],
      setMessage = _useHook[1];

  return {
    message: message,
    setMessage: setMessage
  };
};

export default function YwFilter(props) {
  var maxRows = props.maxRows,
      maxColumns = props.maxColumns,
      minColumns = props.minColumns,
      items = props.items,
      itemWidth = props.itemWidth,
      initialValues = props.initialValues,
      size = props.size,
      cache = props.cache,
      hasSearchBtn = props.hasSearchBtn,
      columnGap = props.columnGap,
      _onSubmit = props.onSubmit,
      onReset = props.onReset,
      onValueChange = props.onValueChange,
      onCreate = props.onCreate,
      others = _objectWithoutPropertiesLoose(props, _excluded2);

  var _items = [{
    component: QueryForm,
    type: 'void',
    componentProps: {
      minColumns: minColumns,
      maxColumns: maxColumns,
      columnGap: columnGap,
      rowGap: 12,
      itemWidth: itemWidth,
      maxRows: maxRows
    },
    children: items
  }];
  var form = useMemo(function () {
    return createForm({
      initialValues: initialValues,
      effects: function effects() {
        onFormInit(function (form) {
          onCreate(form);
        });
        onFormValuesChange(function (form) {
          onValueChange(form.getValuesIn());
        });
      }
    });
  }, []);
  var message = cache.message,
      setMessage = cache.setMessage;
  useEffect(function () {
    message && form.setValues(_extends({}, initialValues, message));
  }, [message]);
  useKeyPress('enter', function () {
    others.useKeyPress && form.submit().then(function (values) {
      _onSubmit(values);

      isFunction(setMessage) && setMessage(undefined);
    });
  }); // useEffect(() => {
  //   initialValues && form.setValues({ ...initialValues, ...message });
  // }, [initialValues]);

  return /*#__PURE__*/React.createElement("div", _extends({
    className: styles['yw-filter']
  }, others), /*#__PURE__*/React.createElement(FormProvider, {
    form: form
  }, /*#__PURE__*/React.createElement("div", {
    className: styles['form-container']
  }, /*#__PURE__*/React.createElement(YwJsonForm, {
    style: {
      flex: 1
    },
    buttons: [],
    size: size,
    layoutProps: {
      colon: false
    },
    items: _items,
    form: form
  }), hasSearchBtn && /*#__PURE__*/React.createElement(Observer, null, function () {
    return /*#__PURE__*/React.createElement("div", {
      className: styles["group-btn-" + (!obs.value ? 'col' : 'line')]
    }, /*#__PURE__*/React.createElement(Submit, {
      onSubmit: function onSubmit(values) {
        _onSubmit(values);

        isFunction(setMessage) && setMessage(values);
      }
    }, "\u67E5\u8BE2"), /*#__PURE__*/React.createElement(Reset, {
      onClick: function onClick() {
        if (isFunction(onReset)) {
          form.reset().then(function () {
            onReset(form);
          });
          return false;
        } else {
          form.reset().then(function () {
            form.submit().then(function (values) {
              _onSubmit(values);

              isFunction(setMessage) && setMessage(undefined);
            });
          });
        }
      }
    }, "\u91CD\u7F6E"));
  }))));
}
YwFilter.useCache = useCache;
YwFilter.defaultProps = {
  maxRows: 2,
  minColumns: 1,
  itemWidth: 328,
  columnGap: 20,
  items: [],
  hasSearchBtn: true,
  initialValues: {},
  children: null,
  cache: {},
  onSubmit: function onSubmit() {},
  useKeyPress: true,
  onCreate: function onCreate() {},
  onValueChange: function onValueChange() {}
};